"""
pyanalog is a redirect package.

Please use 'analogpy' instead:

    pip install analogpy
    import analogpy

This package exists only to reserve the name on PyPI.
"""

import warnings

warnings.warn(
    "pyanalog is deprecated. Please use 'import analogpy' instead.",
    DeprecationWarning,
    stacklevel=2
)

# Re-export everything from analogpy
from analogpy import *
